Module model

Module model 

Re-exports

pub use device::Device;
pub use model_error::ModelError;
pub use rtu::RTU;

Modules

device
This model is a high level abstraction of a device. It is serializable and meant to be sent through the network between web servers. It contains an implementation to talk with the hardware through the drivers also provided by this crate.
model_error
rtu

Traits

SCADADevice
An abstraction of a field device that can be polled and set