Crate brewdrivers[−][src]
Low level drivers for the Navasota Brewing Company’s brewing control system.
This library is one of a set of repositories in the Brewery Control System project of the Navasota Brewing Company. It contains low level drivers for devices we use in the brewing process.
Each module in this library will contain a different set of drivers. For instance, the omega
module contains drivers for OMEGA Engineering devices, and the relays module provides drivers
for any type of relay board.
New drivers will be added as needed. See the examples/ directory
to see how to use this library, and see the organization readme for more information about the
hardware and project as a whole.
Modules
| modbus | A generic Modbus RTU instrument |
| omega | Drivers for OMEGA Engineering instruments. |
| relays | Drivers for relay boards. |